==> oda_api-1.1.2.tar.gz: oda_api-1.1.2/README.md <==
oda_api
==========================================

[![PyPI version](https://badge.fury.io/py/oda-api.svg)](https://badge.fury.io/py/oda-api)
![Upload Python Package](https://github.com/cdcihub/oda_api/workflows/Upload%20Python%20Package/badge.svg)
![Prose Linting](https://github.com/volodymyrss/integral-isgri-rate-meaning/workflows/Prose%20Linting/badge.svg)
![Executing Notebook](https://github.com/volodymyrss/integral-isgri-rate-meaning/workflows/Executing%20Notebook/badge.svg)

*API for cdci_data_analysis*

What's the license?
-------------------

oda_api is distributed under the terms of The MIT License.

Who's responsible?
-------------------
Andrea Tramacere

Volodymyr Savchenko

Astronomy Department of the University of Geneva

Chemin d'Ecogia 16
CH-1290 Versoix
Switzerland



Download the code
-------------------
   - pip install --upgrade oda-api

Installation
-------------------

This is the recommended method, equally in [conda environment](https://docs.conda.io/projects/conda/en/latest/user-guide/tasks/manage-environments.html#using-pip-in-an-environment).

```bash
$ pip install oda-api --upgrade
```


Alternatively, download source and use Anaconda

```bash
git clone https://github.com/oda-hub/oda_api oda_api
cd oda_api
conda install -c conda-forge --file requirements.txt
python setup.py install
```
    

Documentation
-------------------
https://oda-api.readthedocs.io/en/latest/

[![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/cdcihub/oda_api/master)

==> oda_api-1.1.13.tar.gz: oda_api-1.1.13/README.md <==
oda_api
==========================================

[![PyPI version](https://badge.fury.io/py/oda-api.svg)](https://badge.fury.io/py/oda-api)
![Upload Python Package](https://github.com/cdcihub/oda_api/workflows/Upload%20Python%20Package/badge.svg)
![Prose Linting](https://github.com/volodymyrss/integral-isgri-rate-meaning/workflows/Prose%20Linting/badge.svg)
![Executing Notebook](https://github.com/volodymyrss/integral-isgri-rate-meaning/workflows/Executing%20Notebook/badge.svg)
[![Python package](https://github.com/oda-hub/oda_api/actions/workflows/python-package.yml/badge.svg)](https://github.com/oda-hub/oda_api/actions/workflows/python-package.yml)

*API for cdci_data_analysis*

What's the license?
-------------------

oda_api is distributed under the terms of The MIT License.

Who's responsible?
-------------------
Andrea Tramacere

Volodymyr Savchenko

Astronomy Department of the University of Geneva

Chemin d'Ecogia 16
CH-1290 Versoix
Switzerland



Download the code
-------------------
   - pip install --upgrade oda-api

Installation
-------------------

This is the recommended method, equally in [conda environment](https://docs.conda.io/projects/conda/en/latest/user-guide/tasks/manage-environments.html#using-pip-in-an-environment).

```bash
$ pip install oda-api --upgrade
```


Alternatively, download source and use Anaconda

```bash
git clone https://github.com/oda-hub/oda_api oda_api
cd oda_api
conda install -c conda-forge --file requirements.txt
python setup.py install
```
    

Documentation
-------------------
https://oda-api.readthedocs.io/en/latest/

[![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/cdcihub/oda_api/master)
